==> haskell-tasty-golden-2.3.2-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-4TPXsMqwvJvK7dV76ZGgCh
key: tasty-golden-2.3.2-4TPXsMqwvJvK7dV76ZGgCh
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: 8e0470fda753a71e73cee20b91ca6c4b
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-4TPXsMqwvJvK7dV76ZGgCh
depends:
    base-4.11.1.0 tasty-1.1.0.3-DfrquUrmEWG90mJgnRwHvl
    bytestring-0.10.8.2 process-1.6.3.0 mtl-2.2.2
    optparse-applicative-0.14.2.0-K7gRnp080wgGVRM5iNUBl1 filepath-1.4.2
    temporary-1.3-EBuERSEmtHXE85JeaX8qjS
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO deepseq-1.4.3.0
    containers-0.5.11.0 directory-1.3.1.5
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tasty-1.1.0.3-DfrquUrmEWG90mJgnRwHvl=814f05a0ef2ec67b11f2b4b960c24978
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             optparse-applicative-0.14.2.0-K7gRnp080wgGVRM5iNUBl1=f23942b3b87da5fbba8d301e58fc899a
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             temporary-1.3-EBuERSEmtHXE85JeaX8qjS=01d519c7432efc4de9e320255c42d692
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-golden-2.3.2-8-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-golden.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-golden
version: 2.3.2
id: tasty-golden-2.3.2-46D4Y731fda9zxjxiA7poV
key: tasty-golden-2.3.2-46D4Y731fda9zxjxiA7poV
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka
homepage: https://github.com/feuerbach/tasty-golden
synopsis: Golden tests support for tasty
description:
    This package provides support for «golden testing».
    A golden test is an IO action that writes its result to a file.
    To pass the test, this output file should be identical to the corresponding
    «golden» file, which contains the correct result for the test.
    To get started with golden testing and this library, see
    <https://ro-che.info/articles/2017-12-04-golden-tests Introduction to golden testing>.
category: Testing
abi: 75b7c706585c6c7da9a89ab7bbf63a6f
exposed: True
exposed-modules:
    Test.Tasty.Golden Test.Tasty.Golden.Advanced
    Test.Tasty.Golden.Manage
hidden-modules: Test.Tasty.Golden.Internal
import-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
library-dirs: /usr/lib/ghc-8.4.3/site-local/tasty-golden-2.3.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/tasty-golden-2.3.2
hs-libraries: HStasty-golden-2.3.2-46D4Y731fda9zxjxiA7poV
depends:
    base-4.11.1.0 tasty-1.1.0.3-FIVcWyFmwoz8YcurpeH6hw
    bytestring-0.10.8.2 process-1.6.3.0 mtl-2.2.2
    optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4 filepath-1.4.2
    temporary-1.3-5bqbhVmzNQ312di8hYfYNy
    tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO deepseq-1.4.3.0
    containers-0.5.11.0 directory-1.3.1.5
    async-2.2.1-B6m2kYywRJu7nicgTBxsJe
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             tasty-1.1.0.3-FIVcWyFmwoz8YcurpeH6hw=dda03f3c16f751757f36e25981e6268e
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
             process-1.6.3.0=abb0cfe39ff8617a198f540a7db854a9
             mtl-2.2.2=3cf3b316ad8e985e039ee3b498a98253
             optparse-applicative-0.14.3.0-3858SIdIcA6IDhFDNu1Ke4=aab631eb7769f669f53846ea7d62d855
             filepath-1.4.2=f8b35940dbf3bb5331e1c5ab9738687d
             temporary-1.3-5bqbhVmzNQ312di8hYfYNy=de64fcd47729d5cddeae86a4546a93c2
             tagged-0.8.6-8akQ1aZG2N2GFJpoB5eGXO=4bf567357cce5e796341c1faefad6985
             deepseq-1.4.3.0=00d8faa7363cb0be9acd709ef6549e22
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             directory-1.3.1.5=e563da47c8e71ee27761a9b9d172f1ec
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=64d83880768398851ddaf7518afebeee
haddock-interfaces: /usr/share/doc/haskell-tasty-golden/html/tasty-golden.haddock
haddock-html: /usr/share/doc/haskell-tasty-golden/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
